#region Copyright Syncfusion Inc. 2001 - 2005
//
//  Copyright Syncfusion Inc. 2001 - 2005. All rights reserved.
//
//  Use of this code is subject to the terms of our license.
//  A copy of the current license can be obtained at any time by e-mailing
//  licensing@syncfusion.com. Any infringement will be prosecuted under
//  applicable laws. 
//
#endregion

using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using Syncfusion.Pdf;

namespace EssentialPDFSamples
{
	/// <summary>
	/// Summary description for WebForm1.
	/// </summary>
	public class WebForm1 : System.Web.UI.Page
	{
		protected System.Web.UI.WebControls.Label Label1;
		protected System.Web.UI.WebControls.CheckBox CheckBox1;
		protected System.Web.UI.WebControls.Button Button1;
		private DataSet dsNorthWind;
		
		private void Page_Load(object sender, System.EventArgs e)
		{
			// Put user code to initialize the page here
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.Button1.Click += new System.EventHandler(this.Button1_Click);
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		private void Button1_Click(object sender, System.EventArgs e)
		{
			//Create a new PDF Document. This object represents the whole PDF document.
			//This document had One page by default. Additional pages have to be added.
			PDFDocument pdfDoc = new PDFDocument();	
			
			//Adding Header
			this.AddHeader(pdfDoc,"Syncfusion Essential PDF","Northwind Customers");

			//Accessing the first page in the pages collection.
			IPDFPage firstPage = pdfDoc.Pages[0];
			
			//Create a new PDF Table
			ITable table = pdfDoc.CreateTable();
			
			//Get the Northwind DataTable
			dsNorthWind = GetDataSet();

			//Importing a DataTable
			table.DataMember = dsNorthWind.Tables[0].TableName;
			table.DataSource = dsNorthWind;
			table.ConfigureTable( dsNorthWind.Tables[0] );


			//Setting Table Properties
			table.Style.BorderColors.All = Color.FromArgb( 0x82, 0x2e, 0x1b );
			table.Style.BordersWidth.All = 1;
			
			//Fonts to be used inside the table header rows and body rows.
			IPDFFont customersTableTitleFont = pdfDoc.Fonts.Add( new Font( "courier", 6, FontStyle.Bold )  );
			IPDFFont customersTableBodyFont = pdfDoc.Fonts.Add( new Font( "courier", 6, FontStyle.Regular )  );
	
			//Format the Header Rows
			for( int i = 0, len = table.Columns.Count; i < len; ++i )
			{
				table.Header[0].Cells[i].Style.BackColor = Color.FromArgb( 252, 172, 38 );
				table.Header[0].Cells[i].Style.TextFont = customersTableTitleFont;
				table.Header[0].Cells[i].Style.BorderColors.All = Color.FromArgb( 0x82, 0x2e, 0x1b );
				table.Header[0].Cells[i].Style.BordersWidth.All = 0;
			}

			//Format the tables
			for( int i = 0; i < table.Rows.Count; ++i )
			{
				for(int j=0; j< table.Columns.Count;++j)
				{
					table.Rows[i].Cells[j].Style.BackColor = Color.FromArgb( 219, 226, 242 );
					table.Rows[i].Cells[j].Style.TextFont = customersTableBodyFont;
					table.Rows[i].Cells[j].Style.BorderColors.All = Color.FromArgb( 0x82, 0x2e, 0x1b );
					table.Rows[i].Cells[j].Style.BordersWidth.All = 0;
				}
			}

			//To make the Table span over multiple pages without getting cut.
			table.PageBreakBehavior = AutoBreakBehavior.FullBreak;

			float totalDataColWidth = 0;
			for( int i = 0, len = table.Columns.Count; i < len; ++i )
			{
				totalDataColWidth = totalDataColWidth + pdfDoc.Graphics.MeasureString(table.Columns[ i ].DataColumnName,customersTableTitleFont).Width;
			}

			for( int i = 0, len = table.Columns.Count; i < len; ++i )
			{
				table.Columns[ i ].Width = pdfDoc.Graphics.MeasureString(table.Columns[ i ].DataColumnName,customersTableTitleFont).Width + ((pdfDoc.Pages[0].DrawingWidth -totalDataColWidth)/table.Columns.Count );
			}		

			table.RepeateHeader = true;
			
			//Draw the table to the specified page
			table.Publish( new PointF( 0, 0 ),pdfDoc.Pages[0]);

			//Stream the output to the browser.	
			if(this.CheckBox1.Checked)
			{
				pdfDoc.Save("Sample.pdf",Response,HttpReadType.Open);
			}
			else
			{
				pdfDoc.Save("Sample.pdf",Response,HttpReadType.Save);
			}
		}

		 private DataSet GetDataSet()
		 {
			//Create the Blank DataSet
			DataSet dataSet11 = new DataSet();
			//Read the data from XML.
			dataSet11.ReadXml(Server.MapPath(@"Data\customers.xml"));

			return dataSet11;		

		}
        private void AddHeader( IPDFDocument doc, string title, string description )
		{
			if( doc == null )
			{
				throw new ArgumentNullException( "doc" );
			}

			if( title == null )
			{
				throw new ArgumentNullException( "title" );
			}

			const int offset = 10;

			// Add the header   
			Syncfusion.Pdf.ITemplate header = doc.CreateTemplate();
			//Add the font that will be used in the header
			IPDFFont font = doc.Fonts.Add( FontBaseFamily.HelveticaBold );
			//Define font properties for the header.
			font.Size = 24;
			//Just to make sure that we have enough space in the header.
			float doubleHeight = font.Height * 2;
			Color activeColor = Color.FromArgb( 44, 71, 120 );

			//Add Logo Image
			//IPDFGraphicState is used for setting properties of all drawing objects.
			IPDFGraphicState props = doc.CreateGraphicState();
			SizeF imageSize = new SizeF( 110f, 35f );
			//Locating the logo on the right corner of the Drawing Surface
			PointF imageLocation = new PointF( doc.LastPage.DrawingWidth - imageSize.Width, 15 );      
			props.Padding = new PDFPadding( offset, offset, 0, 0 );
			doc.Images.Add(Server.MapPath(@"Data\logo.jpg"));
			IPDFImage logoImage = doc.Images[0];
			//Draw the image in the Header.
			header.Graphics.DrawImage(imageLocation,logoImage,imageSize, props );

			//Add Title Tab
			props = doc.CreateGraphicState();
			props.TextAlignment = TextAlignment.Center;
			props.ForeColor = activeColor;
			props.Scale( 0.8f, 0.7f );
			props.Padding = new PDFPadding( offset * 2, 0, ( int )imageSize.Width, 0 );
			header.Graphics.DrawMultiText( offset, 5, doc.LastPage.DrawingWidth, font.Height, title, font, props );

			SizeF headerSize;
			//Add description tag
			if( description != null && description.Length > 0 )
			{
				headerSize = header.Size;
				font = doc.Fonts.Add( FontBaseFamily.HelveticaOblique );
				font.Size = 8;
				props = doc.CreateGraphicState();
				props.TextAlignment = TextAlignment.Left;
				props.Padding = new PDFPadding( offset, 0, 0, 0 );
				props.ForeColor = Color.Gray;
				header.Graphics.DrawMultiText( 0, headerSize.Height,
					doc.LastPage.DrawingWidth, font.Height, description, font, props );
			}
			//Add the border effect.
			headerSize = header.Size;
			headerSize.Height += 10;
			activeColor = Color.FromArgb( 139, 164, 204 );

			props = doc.CreateGraphicState();
			props.ForeColor = activeColor;
			header.Graphics.DrawLine( 0, 0, headerSize.Width-10, 0 );
			header.Graphics.DrawLine( 0, headerSize.Height, headerSize.Width-10, headerSize.Height );

			header.Graphics.DrawLine( 0, 0, 0, headerSize.Height );

			header.Graphics.DrawLine( headerSize.Width-10, 0, headerSize.Width-10, headerSize.Height );


			props = doc.CreateGraphicState();
			props.LineWidth = 2;
			props.ForeColor = activeColor;
			header.Graphics.DrawLine( 0, 2, headerSize.Width-10, 2, props );
			header.Graphics.DrawLine( 0, headerSize.Height - 2, headerSize.Width-10, headerSize.Height - 2, props );

			header.Graphics.DrawLine( 0, 5, headerSize.Width-10, 5 );
			header.Graphics.DrawLine( 0, headerSize.Height - 5, headerSize.Width-10, headerSize.Height - 5 );

			doc.Header = header;      
		}
	}
}
